package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.IOException;
import java.util.Objects;
import org.apache.bcel.generic.Type;
import org.apache.bcel.util.BCELComparator;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/Method.class */
public final class Method extends FieldOrMethod {
    public static final Method[] EMPTY_ARRAY = new Method[0];
    private static BCELComparator bcelComparator = new BCELComparator() { // from class: org.apache.bcel.classfile.Method.1
        public boolean equals(Object o1, Object o2) {
            Method THIS = (Method) o1;
            Method THAT = (Method) o2;
            return Objects.equals(THIS.getName(), THAT.getName()) && Objects.equals(THIS.getSignature(), THAT.getSignature());
        }

        public int hashCode(Object o) {
            Method THIS = (Method) o;
            return THIS.getSignature().hashCode() ^ THIS.getName().hashCode();
        }
    };
    static final Method[] EMPTY_METHOD_ARRAY = new Method[0];
    private ParameterAnnotationEntry[] parameterAnnotationEntries;

    public static BCELComparator getComparator() {
        return bcelComparator;
    }

    public static void setComparator(BCELComparator comparator) {
        bcelComparator = comparator;
    }

    public Method() {
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public Method(DataInput file, ConstantPool constantPool) throws IOException, ClassFormatException {
        super(file, constantPool);
    }

    public Method(int accessFlags, int nameIndex, int signatureIndex, Attribute[] attributes, ConstantPool constantPool) {
        super(accessFlags, nameIndex, signatureIndex, attributes, constantPool);
    }

    public Method(Method c) {
        super(c);
    }

    @Override // org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitMethod(this);
    }

    public Method copy(ConstantPool constantPool) {
        return (Method) copy_(constantPool);
    }

    public boolean equals(Object obj) {
        return bcelComparator.equals(this, obj);
    }

    public Type[] getArgumentTypes() {
        return Type.getArgumentTypes(getSignature());
    }

    public Code getCode() {
        for (Attribute attribute : super.getAttributes()) {
            if (attribute instanceof Code) {
                return (Code) attribute;
            }
        }
        return null;
    }

    public ExceptionTable getExceptionTable() {
        for (Attribute attribute : super.getAttributes()) {
            if (attribute instanceof ExceptionTable) {
                return (ExceptionTable) attribute;
            }
        }
        return null;
    }

    public LineNumberTable getLineNumberTable() {
        Code code = getCode();
        if (code == null) {
            return null;
        }
        return code.getLineNumberTable();
    }

    public LocalVariableTable getLocalVariableTable() {
        Code code = getCode();
        if (code == null) {
            return null;
        }
        return code.getLocalVariableTable();
    }

    public ParameterAnnotationEntry[] getParameterAnnotationEntries() {
        if (this.parameterAnnotationEntries == null) {
            this.parameterAnnotationEntries = ParameterAnnotationEntry.createParameterAnnotationEntries(getAttributes());
        }
        return this.parameterAnnotationEntries;
    }

    public Type getReturnType() {
        return Type.getReturnType(getSignature());
    }

    public int hashCode() {
        return bcelComparator.hashCode(this);
    }

    public String toString() {
        String access = Utility.accessToString(super.getAccessFlags());
        ConstantUtf8 c = super.getConstantPool().getConstantUtf8(super.getSignatureIndex());
        String signature = c.getBytes();
        ConstantUtf8 c2 = super.getConstantPool().getConstantUtf8(super.getNameIndex());
        String name = c2.getBytes();
        StringBuilder buf = new StringBuilder(Utility.methodSignatureToString(signature, name, access, true, getLocalVariableTable()));
        for (Attribute attribute : super.getAttributes()) {
            if (!(attribute instanceof Code) && !(attribute instanceof ExceptionTable)) {
                buf.append(" [").append(attribute).append("]");
            }
        }
        ExceptionTable e = getExceptionTable();
        if (e != null) {
            String str = e.toString();
            if (!str.isEmpty()) {
                buf.append("\n\t\tthrows ").append(str);
            }
        }
        return buf.toString();
    }
}
